package com.inspect.metadata.robuavtask.service.impl;

import com.inspect.metadata.robuavtask.domain.BasedataPatrolRobUavTask;
import com.inspect.metadata.robuavtask.mapper.BasedataPatrolRobUavTaskMapper;
import com.inspect.metadata.robuavtask.service.IBasedataPatrolRobUavTaskService;

import java.util.List;

import org.springframework.stereotype.Service;

import javax.annotation.Resource;

@Service
public class BasedataPatrolRobUavTaskServiceImpl implements IBasedataPatrolRobUavTaskService {
    @Resource
    private BasedataPatrolRobUavTaskMapper basedataPatrolRobUavTaskMapper;

    public BasedataPatrolRobUavTask selectBasedataPatrolRobUavTaskByPatrolRobUavTaskId(Long patrolRobUavTaskId) {
        return this.basedataPatrolRobUavTaskMapper.selectBasedataPatrolRobUavTaskByPatrolRobUavTaskId(patrolRobUavTaskId);
    }

    public List<BasedataPatrolRobUavTask> selectBasedataPatrolRobUavTaskList(BasedataPatrolRobUavTask basedataPatrolRobuavTask) {
        return this.basedataPatrolRobUavTaskMapper.selectBasedataPatrolRobUavTaskList(basedataPatrolRobuavTask);
    }

    public int insertBasedataPatrolRobUavTask(BasedataPatrolRobUavTask basedataPatrolRobuavTask) {
        return this.basedataPatrolRobUavTaskMapper.insertBasedataPatrolRobUavTask(basedataPatrolRobuavTask);
    }

    public int updateBasedataPatrolRobUavTask(BasedataPatrolRobUavTask basedataPatrolRobuavTask) {
        return this.basedataPatrolRobUavTaskMapper.updateBasedataPatrolRobUavTask(basedataPatrolRobuavTask);
    }

    public int deleteBasedataPatrolRobUavTaskByPatrolRobUavTaskIds(Long[] patrolRobUavTaskIds) {
        return this.basedataPatrolRobUavTaskMapper.deleteBasedataPatrolRobUavTaskByPatrolRobUavTaskIds(patrolRobUavTaskIds);
    }

    public int deleteBasedataPatrolRobUavTaskByPatrolRobUavTaskId(Long patrolRobUavTaskId) {
        return this.basedataPatrolRobUavTaskMapper.deleteBasedataPatrolRobUavTaskByPatrolRobUavTaskId(patrolRobUavTaskId);
    }
}
